@@ -61,6 +61,8 @@ class BSplineApproximator:
 
         points = points.to(self.device)
         
+        l = 100
+        
         splines = torch.zeros(points.shape[0],points.shape[1],points.shape[2]).to(self.device)
         list_of_knots = torch.zeros(points.shape[0],2*(k+1)+n_knots).to(self.device)
         HD_log = torch.zeros(points.shape[0],n_knots+1).to(self.device)
@@ -78,8 +80,6 @@ class BSplineApproximator:
             
             segs = segments[i]
 
-            l = points.shape[1]
-
             seq_of_points_seg, ranges, indices = computeSampling(seq_of_points,
                                                                  segs,
                                                                  l,
